# texture_miner Changelog

All notable changes to this project will be documented in this file.

---

## 1.1.0 | 2023-07-07

### Changed

* Crop large textures to 16×16 pixels

---

## 1.0.0 | 2023.06.15

### Added

* Bedrock Edition support
* CLI argument support
* Nice title for CLI entry point

### Changed

* Lots of refactoring
* Improved documentation
* Made text output more consistent and informative

### Fixed

* Clear temporary directory after use
